.. Organelle Assembler documentation master file, created by
   sphinx-quickstart on Thu Feb 13 16:10:03 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

|Orgasm|
========

Contents:

.. toctree::
   :maxdepth: 2

   install
   oa
   mitochondrion
   algorithms


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
